@@ -1,6 +1,6 @@
 import unittest
-import tsaugmentation as tsag
 from gpforecaster.model.gpf import GPF
+import tsaugmentation as tsag
 import shutil
 
 
@@ -24,11 +24,16 @@ class TestModel(unittest.TestCase):
     def test_predict_shape(self):
         model, like = self.gpf.train(n_iterations=10)
         mean, lower, upper = self.gpf.predict(model, like)
-        print(mean.shape)
         self.assertTrue(mean.shape == (1, self.n, self.s))
 
     def test_results_interval(self):
         model, like = self.gpf.train(n_iterations=100)
         mean, lower, upper = self.gpf.predict(model, like)
-        res = self.gpf.metrics(mean)
+        res = self.gpf.metrics(mean, lower, upper)
         self.assertLess(res['mase']['bottom'], 2.5)
+
+    def test_wall_time(self):
+        model, like = self.gpf.train(n_iterations=10)
+        mean, lower, upper = self.gpf.predict(model, like)
+        res = self.gpf.metrics(mean)
+        self.assertLess(res['wall_time']['wall_time_total'], 100)
